#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh

OLDPW=""
NEWPW=""

set_lighttpd_pw() {
    if [[ -x /usr/bin/htdigest.sh ]]; then
        htdigest.sh -u dssadmin -r dSS11 -p "$1"
        if [ "$?" -eq "1" ]; then
            jsoin_error $ERR_SETUP "Could not set new password, htdigest.sh utility returned error!"
            return $ERR_SETUP
        fi
        PID=`pidof lighttpd`
        if [[ -n "$PID" ]]; then
            kill -HUP $PID
        fi
    else
        json_error $ERR_SETUP "Missing htdigest.sh utility!"
        return $ERR_SETUP
    fi

    return $ERR_OK
}

check_current_pw() {
    HASH=$(echo -n "dssadmin:dSS11:$1" | md5sum | cut -b -32)
    if [[ -f /etc/lighttpd.user ]]; then
        cat /etc/lighttpd.user | grep "$HASH" > /dev/null 2>&1
        if [ "$?" -eq "1" ]; then
            json_error $ERR_PASSWORD "Old password does not match!"
            return $ERR_PASSWORD
        fi
    else
        json_error $ERR_SETUP "Missing lighttpd password configuration!"
        return $ERR_SETUP 
    fi

    return $ERR_OK
}

echo "Content-Type: application/json"
echo ""


if [[ -n "$1" ]]; then 
    OLDPW="$1"
else
    json_error $ERR_PASSWORD "Missing current password!"
    exit 1
fi

if [[ -n "$2" ]]; then
    echo "$2" | grep " " > /dev/null 2>&1
    if [ "$?" -eq "0" ]; then
        json_error $ERR_PASSWORD "Invalid password specified, no spaces allowed!"
        exit 1
    fi
    NEWPW="$2"
else
    json_error $ERR_PASSWORD "Missing new password!"
    exit 1
fi

check_current_pw "$OLDPW"
RETCODE="$?"
if [[ "$RETCODE" -ne "$ERR_OK" ]]; then
    exit $RETCODE
fi

set_lighttpd_pw "$NEWPW"
RETCODE="$?"
if [[ "$RETCODE" -ne "$ERR_OK" ]]; then
    exit $RETCODE
fi

json_ok
